package
Version:
v0.0.0-...-79b36a5
Opens a new window with list of versions in this module.
Published: Sep 3, 2019
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Color32 struct {
color.RGBA `xml:"color,attr,omitempty"`
}
type Color64 struct {
color.RGBA64 `xml:"color,attr,omitempty"`
}
type Colored interface {
Colored32() (R, G, B, A float32)
Colored64() (R, G, B, A float64)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.